import _extends from "@babel/runtime/helpers/extends";

/**
 * File: /src/components/NavLink/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 02-09-2022 06:42:10
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import React, { useCallback } from "react";
import { Platform, StyleSheet } from "react-native";
import { MotiView } from "moti";
import { styled } from "dripsy";
import { useAutoContrast } from "@risserlabs/auto-contrast";
import { Link } from "../Link";
import { Box } from "../Box";
import { Text } from "../Text";
import { useAnimationStateSx } from "../../hooks";
const themeKey = "links";
const defaultStyle = {
  color: "background",
  display: "flex",
  fontWeight: "700" // textDecoration: "none",
  // width: "100%",

};
const StyledLink = styled(Link, {
  themeKey,
  defaultVariant: "nav"
})(defaultStyle);
const StyledText = styled(Text, {
  themeKey,
  defaultVariant: "nav"
})(defaultStyle);
export const NavLink = props => {
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  const style = StyleSheet.flatten([{
    borderRadius: 2
  }, StyleSheet.flatten(props.style || {})]);
  const animationState = useAnimationStateSx({
    from: {},
    to: {
      backgroundColor: "transparent"
    },
    hover: {
      backgroundColor: style.backgroundColor || sx.backgroundColor || sx.bg || "highlight"
    }
  });
  const handleEnter = useCallback(() => {
    animationState.transitionTo("hover");
  }, []);
  const handleLeave = useCallback(() => {
    animationState.transitionTo("to");
  }, []);

  function renderEvents(children) {
    if (Platform.OS === "web") {
      return /*#__PURE__*/React.createElement("div", {
        onMouseEnter: handleEnter,
        onMouseLeave: handleLeave
      }, children);
    }

    return /*#__PURE__*/React.createElement(Box, {
      onPressIn: handleEnter,
      onPressOut: handleLeave
    }, children);
  }

  function renderLink() {
    if (props.href === "#!") {
      const textProps = { ...props
      };
      delete textProps.href;
      return /*#__PURE__*/React.createElement(StyledText, _extends({}, props, {
        sx: sx
      }));
    }

    return /*#__PURE__*/React.createElement(StyledLink, _extends({}, props, {
      sx: sx
    }));
  }

  return /*#__PURE__*/React.createElement(MotiView, {
    state: animationState,
    style: style,
    transition: {
      type: "timing",
      duration: 200
    }
  }, renderEvents(renderLink()));
};
//# sourceMappingURL=index.js.map