/**
 * File: /src/components/Button/props.ts
 * Project: @native-theme-ui/core
 * File Created: 05-07-2022 07:43:20
 * Author: Clay Risser
 * -----
 * Last Modified: 06-09-2022 01:34:02
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { MotiPressableProps } from "moti/interactions";
import { Sx, SxProp } from "dripsy";
import { DripsyStyledProps } from "../../types";
import { createUseSplitProps, splitPropsGroups } from "../../util";
import { TextProps } from "../Text";

export type BasePropsBucket = DripsyStyledProps<MotiPressableProps> & {
  hidden?: boolean;
};

export type TextPropsBucket = TextProps;

export type MotiPropsBucket = {
  animateSx?: SxProp;
  exitSx?: SxProp;
  fromSx?: SxProp;
};

export const useSplitProps = createUseSplitProps<
  ButtonProps,
  {
    baseProps: BasePropsBucket;
    motiProps: MotiPropsBucket;
    textProps: TextPropsBucket;
  },
  {
    baseSx: Sx;
    textSx: Sx;
    innerSx: Sx;
  },
  {
    baseStyle: Record<string, unknown>;
    textStyle: Record<string, unknown>;
    innerStyle: Record<string, unknown>;
  }
>(
  {
    textProps: "autoContrast",
    motiProps: splitPropsGroups.props.moti,
  },
  {
    textSx: splitPropsGroups.sx.text,
    innerSx: splitPropsGroups.sx.inner,
  }
);

export type ButtonProps = BasePropsBucket & TextPropsBucket & MotiPropsBucket;
