/**
 * File: /src/components/Heading/H3.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 01-09-2022 12:27:37
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { FC, ComponentProps } from "react";
import { AutoContrast, useAutoContrast } from "@risserlabs/auto-contrast";
import { Sx, styled } from "dripsy";
import { H1 as HtmlH3 } from "@expo/html-elements";

const themeKey = "text";

const defaultStyle: Sx = {
  fontFamily: "h3",
  fontWeight: "h3",
};

const StyledH3 = styled(HtmlH3, {
  themeKey,
  defaultVariant: "h3",
})(defaultStyle);

export type H3Props = ComponentProps<typeof StyledH3> & {
  autoContrast?: AutoContrast;
};

export const H3: FC<H3Props> = (props: H3Props) => {
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  return <StyledH3 {...props} sx={sx}></StyledH3>;
};
