/**
 * File: /src/components/Heading/H5.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 01-09-2022 12:27:12
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { FC, ComponentProps } from "react";
import { AutoContrast, useAutoContrast } from "@risserlabs/auto-contrast";
import { Sx, styled } from "dripsy";
import { H1 as HtmlH5 } from "@expo/html-elements";

const themeKey = "text";

const defaultStyle: Sx = {
  fontFamily: "h5",
  fontWeight: "h5",
};

const StyledH5 = styled(HtmlH5, {
  themeKey,
  defaultVariant: "h5",
})(defaultStyle);

export type H5Props = ComponentProps<typeof StyledH5> & {
  autoContrast?: AutoContrast;
};

export const H5: FC<H5Props> = (props: H5Props) => {
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  return <StyledH5 {...props} sx={sx}></StyledH5>;
};
