/**
 * File: /src/components/Input/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 01-09-2022 12:29:30
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { ComponentProps, FC } from "react";
import { Sx, styled } from "dripsy";
import { TextInput } from "react-native";
import { useAutoContrast, AutoContrast } from "@risserlabs/auto-contrast";

const themeKey = "forms";

const defaultStyle: Sx = {
  borderRadius: 4,
  borderStyle: "solid",
  borderWidth: 1,
  color: "text",
  fontSize: 1,
  lineHeight: 1,
  p: 2,
};

const StyledTextInput = styled(TextInput, {
  themeKey,
  defaultVariant: "input",
})(defaultStyle);

export type InputProps = ComponentProps<typeof StyledTextInput> & {
  autoContrast?: AutoContrast;
};

export const Input: FC<InputProps> = (props: InputProps) => {
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  return <StyledTextInput {...props} sx={sx} />;
};
