/**
 * File: /src/components/Paragraph/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 20-06-2022 05:48:50
 * Author: Clay Risser
 * -----
 * Last Modified: 01-09-2022 12:28:59
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { FC, ComponentProps } from "react";
import { AutoContrast, useAutoContrast } from "@risserlabs/auto-contrast";
import { P } from "@expo/html-elements";
import { Sx, styled } from "dripsy";

const themeKey = "text";

const defaultStyle: Sx = {
  fontFamily: "paragraph",
  fontWeight: "paragraph",
};

const StyledP = styled(P, {
  themeKey,
  defaultVariant: "h2",
})(defaultStyle);

export type ParagraphProps = ComponentProps<typeof StyledP> & {
  autoContrast?: AutoContrast;
};

export const Paragraph: FC<ParagraphProps> = (props: ParagraphProps) => {
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  return <StyledP {...props} sx={sx}></StyledP>;
};
