/**
 * File: /src/components/Select/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 17-06-2022 06:47:48
 * Author: Harikittu46
 * -----
 * Last Modified: 30-08-2022 06:02:18
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import React, { FC, ComponentProps } from "react";
import { AutoContrast, useAutoContrast } from "@risserlabs/auto-contrast";
import { Platform } from "react-native";
import { SxProp, styled, Sx } from "dripsy";
import { Picker, PickerItemProps } from "@react-native-picker/picker";

const themeKey = "forms";

const defaultStyle: Sx = {
  color: "text",
  // fontSize: "inherit",
  // lineHeight: "inherit",
  appearance: "none",
  border: "1px solid",
  borderColor: "blue",
  borderRadius: 4,
  display: "flex",
  p: 2,
  width: "100%",
};

const StyledPicker = styled(Picker, {
  themeKey,
  defaultVariant: "select",
})(({ showCursor }: { showCursor: boolean }) => ({
  ...Platform.select({
    web: {
      cursor: showCursor ? "pointer" : "default",
    },
  }),
  ...defaultStyle,
}));

type StyledPickerProps = ComponentProps<typeof StyledPicker>;

export type SelectProps = Omit<StyledPickerProps, "showCursor"> & {
  autoContrast?: AutoContrast;
  disabled?: boolean;
  sx?: SxProp;
};

export const Select: FC<SelectProps> & { Option: typeof Option } = (
  props: SelectProps
) => {
  const sx = useAutoContrast(props, defaultStyle, themeKey, true);
  return (
    <StyledPicker
      {...(props as StyledPickerProps)}
      showCursor={!!(props.accessibilityRole === "link" || !props.disabled)}
      sx={sx}
    >
      {props.children}
    </StyledPicker>
  );
};

const Option = Picker.Item;

Select.Option = Option;

export type SelectOptionProps = PickerItemProps;
